about summary refs log tree commit diff
path: root/src/test/compile-fail/issue-5883.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/test/compile-fail/issue-5883.rs')
-rw-r--r--src/test/compile-fail/issue-5883.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/compile-fail/issue-5883.rs b/src/test/compile-fail/issue-5883.rs
index e6ac30139c3..9ff957b6e6d 100644
--- a/src/test/compile-fail/issue-5883.rs
+++ b/src/test/compile-fail/issue-5883.rs
@@ -15,8 +15,8 @@ struct Struct {
 }
 
 fn new_struct(r: A+'static)
-    -> Struct { //~^  ERROR the trait `core::kinds::Sized` is not implemented
-    //~^ ERROR the trait `core::kinds::Sized` is not implemented
+    -> Struct { //~^  ERROR the trait `core::marker::Sized` is not implemented
+    //~^ ERROR the trait `core::marker::Sized` is not implemented
     Struct { r: r }
 }